abacusai.eda_forecasting_analysis — AbacusAI documentation

# `abacusai.eda_forecasting_analysis`

## Module Contents

### Classes

`EdaForecastingAnalysis` | Eda Forecasting Analysis of the latest version of the data.

class abacusai.eda_forecasting_analysis.EdaForecastingAnalysis(client, primaryKeys=None, forecastingTargetFeature=None, timestampFeature=None, forecastFrequency=None, salesAcrossTime={}, cummulativeContribution={}, missingValueDistribution={}, historyLength={}, numRowsHistogram={}, productMaturity={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Eda Forecasting Analysis of the latest version of the data.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - primaryKeys (list) – Name of the primary keys in the data

    - forecastingTargetFeature (str) – Feature in the data that represents the target.

    - timestampFeature (str) – Feature in the data that represents the timestamp column.

    - forecastFrequency (str) – Frequency of data, could be hourly, daily, weekly, monthly, quarterly or yearly.

    - salesAcrossTime (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across time

    - cummulativeContribution (ForecastingAnalysisGraphData) – Data showing what percent of items contribute to what amount of sales.

    - missingValueDistribution (ForecastingAnalysisGraphData) – Data showing missing or null value distribution

    - historyLength (ForecastingAnalysisGraphData) – Data showing length of history distribution

    - numRowsHistogram (ForecastingAnalysisGraphData) – Data showing number of rows for an item distribution

    - productMaturity (ForecastingAnalysisGraphData) – Data showing length of how long a product has been alive with average, p10, p90 and median

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict